@@ -40,6 +40,7 @@ class Stream_Enhancer:
     speedx= (2,4)
     speedy= (2,5)
 
+
     avi = (8,0) #
     jpg = (9,0) #
 
@@ -50,9 +51,11 @@ class Stream_Enhancer:
     # trh= (2,2) #
     # hist=(2,3)
     # dm=  (2,4) #  it is veeery long
-    blr= (2,0) #
-    trh= (3,0) #
+    blr =(2,0) #
+    trh =(3,0) #
     hist=(4,0)
+    rot =(5,0)
+
     dm=  (2,4) #  it is veeery long
 
 
@@ -100,6 +103,7 @@ class Stream_Enhancer:
         if (row,col) == self.trh:  return (150,0,150) #
         if (row,col) == self.hist: return (0,120,150) # brown
         if (row,col) == self.dm:   return (50,100,250) # orange
+        if (row,col) == self.rot:  return (150,120,150) #
 
 
         # left side
@@ -347,7 +351,12 @@ class Stream_Enhancer:
         #print(pos)
         self.textbox(txt, pos , bgcolor= self.RC_COLOR(row,col) , target = target_frame)
 
-#-------------------------------------------- ENDOF LABELS----------
+    #-------------------------------------------- ENDOF LABELS----------
+
+
+    def rotate180(self):
+        self.frame = cv2.rotate(self.frame, cv2.ROTATE_180)
+
     def save_background(self):
         cv2.imwrite( self.BGFILE , self.frame ) # nicely saved
         self.frame_bg = self.frame.copy() # else artifacts remain
