@@ -191,6 +191,10 @@ setInterval(doDate, 200);
    <button style="width:100%" name="rot0" value="ROT0">rot0</button>
    <button style="width:100%" name="rot180" value="ROT180">rot180</button>
  </td>
+ <td>
+   <button style="width:100%" name="live" value="LIVE">live</button>
+   <button style="width:100%" name="fixed" value="FIXED">fixed</button>
+ </td>
 </tr>
 </table>
 
@@ -343,6 +347,11 @@ def cross():
         if request.form.get('rot180') == 'ROT180':
             mmwrite(f"rotate180 True" )
 
+        if request.form.get('live') == 'LIVE':
+            mmwrite(f"fixed_image None" )
+        if request.form.get('fixed') == 'FIXED':
+            mmwrite(f'fixed_image "beamon.jpg"' )
+
 
         # ---------------------------------------------- Cross controls
         if cross_on:
